==> ejc-equipment-api-3.0.0-20200704.061654-77-sources.jar: com/ejianc/business/equipment/vo/RentUseRecordVO.java <==
package com.ejianc.business.equipment.vo;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * <p>
 * 租赁设备使用记录
 * </p>
 *
 * @author yqls
 * @since 2020-06-11
 */
@TableName("ejc_equipment_rent_use_record")
public class RentUseRecordVO extends BaseVO {

    private static final long serialVersionUID = 1L;

    /**
     * 合同编码
     */
    private String billCode;

    /**
     * 设备供应商名称
     */
    private String supplierName;

    /**
     * 设备供应商主键
     */
    private Long supplierId;

    /**
     * 合同名称
     */
    private String contractName;

    /**
     * 合同主键
     */
    private Long contractId;

    /**
     * 项目主键
     */
    private Long projectId;

    /**
     * 项目名称
     */
    private String projectName;

    /**
     * 开始日期
     */
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date startDate;

    /**
     * 结束日期
     */
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date endDate;

    /**
     * 使用部位主键
     */
    private Long partId;

    /**
     * 使用金额
     */
    private BigDecimal useMny;
    /**
     * 合同金额(含税)
     */
    private BigDecimal showUseMny;
    public BigDecimal getShowUseMny() {
        if(null != this.useMny) {
            return this.useMny.setScale(2, BigDecimal.ROUND_HALF_UP);
        }
        return new BigDecimal(0).setScale(2, BigDecimal.ROUND_HALF_UP);
    }

    /**
     * 经办人名称
     */
    private String employeeName;

    /**
     * 经办人
     */
    private Long employeeId;

    /**
     * 备注
     */
    private String memo;

    /**
     * 单据状态（审批必须字段）
     */
    private Integer billState;

    /**
     * 合同状态：1-履约, 2-中止，3-终止，4-废除，5-封账
     */
    private String contractStatus;

    /**
     * 组织
     */
    private Long orgId;

    /**
     * 是否使用
     */
    private Integer useFlag;

    /**
     * 设备名称合集
     */
    private String equipmentName;
    // 设备明细子表
    private List<RentUseRecordDetailVO> rentdetail = new ArrayList<>();

    // 其他费用子表
    private List<RentUseRecordFeeVO> rentfee = new ArrayList<>();

    public List<RentUseRecordDetailVO> getRentdetail() {
        return rentdetail;
    }

    public void setRentdetail(List<RentUseRecordDetailVO> rentdetail) {
        this.rentdetail = rentdetail;
    }

    public List<RentUseRecordFeeVO> getRentfee() {
        return rentfee;
    }

    public void setRentfee(List<RentUseRecordFeeVO> rentfee) {
        this.rentfee = rentfee;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }

    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Date getStartDate() {
        return startDate;
    }

    public void setStartDate(Date startDate) {
        this.startDate = startDate;
    }
    public Date getEndDate() {
        return endDate;
    }

    public void setEndDate(Date endDate) {
        this.endDate = endDate;
    }
    public Long getPartId() {
        return partId;
    }

    public void setPartId(Long partId) {
        this.partId = partId;
    }
    public BigDecimal getUseMny() {
        return useMny;
    }

    public void setUseMny(BigDecimal useMny) {
        this.useMny = useMny;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getContractStatus() {
        return contractStatus;
    }

    public void setContractStatus(String contractStatus) {
        this.contractStatus = contractStatus;
    }

    public Integer getUseFlag() {
        return useFlag;
    }

    public void setUseFlag(Integer useFlag) {
        this.useFlag = useFlag;
    }
    public String getEquipmentName() {
        return equipmentName;
    }

    public void setEquipmentName(String equipmentName) {
        this.equipmentName = equipmentName;
    }
    @ReferSerialTransfer(referCode="market-project")
    public Long getProjectId() {
        return projectId;
    }

    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    @ReferSerialTransfer(referCode="idm-org")
    public Long getOrgId() {
        return orgId;
    }

    @ReferDeserialTransfer
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    @ReferSerialTransfer(referCode="idm-employee")
    public Long getEmployeeId() {
        return employeeId;
    }

    @ReferDeserialTransfer
    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }


    @ReferSerialTransfer(referCode="support-supplier")
    public Long getSupplierId() {
        return supplierId;
    }

    @ReferDeserialTransfer
    public void setSupplierId(Long supplierId) {
        this.supplierId = supplierId;
    }
    @ReferSerialTransfer(referCode="equipment-rent-contract")
    public Long getContractId() {
        return contractId;
    }
    @ReferDeserialTransfer
    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
}

==> ejc-equipment-api-3.0.0-20200711.035111-104-sources.jar: com/ejianc/business/equipment/vo/RentUseRecordVO.java <==
package com.ejianc.business.equipment.vo;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * <p>
 * 租赁设备使用记录
 * </p>
 *
 * @author yqls
 * @since 2020-06-11
 */
@TableName("ejc_equipment_rent_use_record")
public class RentUseRecordVO extends BaseVO {

    private static final long serialVersionUID = 1L;

    /**
     * 合同编码
     */
    private String billCode;
    private String billStateName;

    /**
     * 设备供应商名称
     */
    private String supplierName;

    /**
     * 设备供应商主键
     */
    private Long supplierId;

    /**
     * 合同名称
     */
    private String contractName;

    /**
     * 合同主键
     */
    private Long contractId;

    /**
     * 项目主键
     */
    private Long projectId;

    /**
     * 项目名称
     */
    private String projectName;

    /**
     * 开始日期
     */
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date startDate;

    /**
     * 结束日期
     */
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date endDate;

    /**
     * 使用部位主键
     */
    private Long partId;

    /**
     * 使用金额
     */
    private BigDecimal useMny;
    /**
     * 合同金额(含税)
     */
    private BigDecimal showUseMny;

    public String getBillStateName() {
        return billStateName;
    }

    public void setBillStateName(String billStateName) {
        this.billStateName = billStateName;
    }

    public void setShowUseMny(BigDecimal showUseMny) {
        this.showUseMny = showUseMny;
    }

    public BigDecimal getShowUseMny() {
        if(null != this.useMny) {
            return this.useMny.setScale(2, BigDecimal.ROUND_HALF_UP);
        }
        return new BigDecimal(0).setScale(2, BigDecimal.ROUND_HALF_UP);
    }

    /**
     * 经办人名称
     */
    private String employeeName;

    /**
     * 经办人
     */
    private Long employeeId;

    /**
     * 备注
     */
    private String memo;

    /**
     * 单据状态（审批必须字段）
     */
    private Integer billState;

    /**
     * 合同状态：1-履约, 2-中止，3-终止，4-废除，5-封账
     */
    private String contractStatus;

    /**
     * 组织
     */
    private Long orgId;

    /**
     * 是否使用
     */
    private Integer useFlag;

    /**
     * 设备名称合集
     */
    private String equipmentName;
    // 设备明细子表
    private List<RentUseRecordDetailVO> rentdetail = new ArrayList<>();

    // 其他费用子表
    private List<RentUseRecordFeeVO> rentfee = new ArrayList<>();

    public List<RentUseRecordDetailVO> getRentdetail() {
        return rentdetail;
    }

    public void setRentdetail(List<RentUseRecordDetailVO> rentdetail) {
        this.rentdetail = rentdetail;
    }

    public List<RentUseRecordFeeVO> getRentfee() {
        return rentfee;
    }

    public void setRentfee(List<RentUseRecordFeeVO> rentfee) {
        this.rentfee = rentfee;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }

    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Date getStartDate() {
        return startDate;
    }

    public void setStartDate(Date startDate) {
        this.startDate = startDate;
    }
    public Date getEndDate() {
        return endDate;
    }

    public void setEndDate(Date endDate) {
        this.endDate = endDate;
    }
    public Long getPartId() {
        return partId;
    }

    public void setPartId(Long partId) {
        this.partId = partId;
    }
    public BigDecimal getUseMny() {
        return useMny;
    }

    public void setUseMny(BigDecimal useMny) {
        this.useMny = useMny;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getContractStatus() {
        return contractStatus;
    }

    public void setContractStatus(String contractStatus) {
        this.contractStatus = contractStatus;
    }

    public Integer getUseFlag() {
        return useFlag;
    }

    public void setUseFlag(Integer useFlag) {
        this.useFlag = useFlag;
    }
    public String getEquipmentName() {
        return equipmentName;
    }

    public void setEquipmentName(String equipmentName) {
        this.equipmentName = equipmentName;
    }
    @ReferSerialTransfer(referCode="market-project")
    public Long getProjectId() {
        return projectId;
    }

    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    @ReferSerialTransfer(referCode="idm-org")
    public Long getOrgId() {
        return orgId;
    }

    @ReferDeserialTransfer
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    @ReferSerialTransfer(referCode="idm-employee")
    public Long getEmployeeId() {
        return employeeId;
    }

    @ReferDeserialTransfer
    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }


    @ReferSerialTransfer(referCode="support-supplier")
    public Long getSupplierId() {
        return supplierId;
    }

    @ReferDeserialTransfer
    public void setSupplierId(Long supplierId) {
        this.supplierId = supplierId;
    }
    @ReferSerialTransfer(referCode="equipment-rent-contract")
    public Long getContractId() {
        return contractId;
    }
    @ReferDeserialTransfer
    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
}
